package com.keyware.composeanalysis.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 成分分析任务 实体对象
 * </p>
 *
 * @author liuzongren
 * @since 2024-07-23
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Accessors(chain = true)
@TableName("analysis_task")
public class AnalysisTask implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 逻辑主键ID，UUID
     */
    @TableId("id")
    private String id;

    /**
     * 被测件的名称（上传文件的名称）
     */
    @TableField("file_name")
    private String fileName;

    /**
     * 被测件版本
     */
    @TableField("version")
    private String version;


    /**
     * 成分分析等级
     * 检测特征级别：0文件，1函数 2:代码块 3:行
     */
    @TableField("analysis_level")
    private Integer analysisLevel;

    /**
     * 开源比例阈值，当开源比例超过此阈值，则判断当前文件开源
     */
    @TableField("open_rate_threshold")
    private Integer openRateThreshold;

    /**
     * 当前被测件是否是开源的
     */
    @TableField("open_type")
    private Boolean openType;

    /**
     * 被测件的md5值
     */
    @TableField("md5")
    private String md5;


    /**
     * 被测件的文件总数
     */
    @TableField("file_count")
    private Integer fileCount;


    /**
     * 成分分析的状态
     */
    @TableField("analysis_status")
    private Integer analysisStatus;

    /**
     * 分析开始时间
     */
    @TableField("analysis_start_time")
    private Date analysisStartTime;

    /**
     * 分析结束时间
     */
    @TableField("analysis_end_time")
    private Date analysisEndTime;

    /**
     * 成分分析是否完成（0:未完成 1:分析中 2:已完成）
     */
    @TableField("compose_flag")
    private Integer composeFlag;

    /**
     * 组件分析是否完成（0:未完成 1:分析中 2:已完成）
     */
    @TableField("assembly_flag")
    private Integer assemblyFlag;

    /**
     * 漏洞分析是否完成（0:未完成 1:分析中 2:已完成）
     */
    @TableField("hold_flag")
    private Integer holdFlag;

    /**
     * 许可证分析是否完成（0:未完成 1:分析中 2:已完成）
     */
    @TableField("licence_flag")
    private Integer licenceFlag;

    /**
     * 文件解压缩是否完成（false:未解压  2:true）
     */
    @TableField("decompression_flag")
    private Boolean decompressionFlag = false;

    /**
     * 任务创建时间
     */
    @TableField("create_time")
    private Date createTime;

    /**
     * 任务创建ID
     */
    @TableField("create_user_id")
    private String createUserId;

    /**
     * 分析总耗时
     * 格式为：时-分-秒
     */
    @TableField(exist = false)
    private String analysisUsedTime;

    /**
     * 分析进度
     * 100%
     */
    @TableField(exist = false)
    private String analysisProgress;

}
